pub struct GridFile {
pub id: Uuid,
pub filename: String,
pub details: Option<FileDetails>,
pub metadata: Option<Document>,
/* private fields */
}Expand description
A representation of a file in GridFS
Fields
id: UuidThe file’s ID
filename: StringThe filename of this file
details: Option<FileDetails>Resolved details about the file, if it’s been uploaded already.
metadata: Option<Document>Arbitrary metadata stored in the file’s document
Implementations
Sourceimpl GridFile
impl GridFile
Sourcepub async fn read(&self) -> MResult<GridReader>
pub async fn read(&self) -> MResult<GridReader>
Creates a GridReader to read this file.
Panics: If the GridFS instance has not been attached.
Sourcepub async fn write(self) -> MResult<GridWriter>
pub async fn write(self) -> MResult<GridWriter>
Creates a GridWriter to write this file into GridFS. This method takes ownership of the GridFile, which will be returned by GridWriter::commit()
Panics: If the GridFS instance has not been attached.
Sourcepub fn metadata<T: DeserializeOwned>(&self) -> Option<T>
pub fn metadata<T: DeserializeOwned>(&self) -> Option<T>
Gets the file’s metadata (if present) and attempts to convert it to the specified type. Returns None if no metadata exists or if deserialization fails.
Sourcepub fn untyped_metadata(&self) -> Option<Document>
pub fn untyped_metadata(&self) -> Option<Document>
Returns the raw bson::Document of the metadata, if present.